pub struct WakerPool<const N: usize> { /* private fields */ }
register a waker into the pool
Returns false if the pool is full.
Wake a waiter, and remove it.
Returns false if the pool is empty.
Wake all waiter, and remove it.
returns the number of had waked
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.