pub struct WakerToken<'a, const N: usize> { /* private fields */ }
The token is ownership of a Cell of the pool.

The waker will drop without wake, if the token drop

Implementations

Replace waker

wake it immediately, if is waking.