Struct async_ach_waker::WakerToken
source · [−]pub struct WakerToken<'a, const N: usize> { /* private fields */ }Expand description
The token is ownership of a Cell of the pool.
The waker will drop without wake, if the token drop
pub struct WakerToken<'a, const N: usize> { /* private fields */ }The token is ownership of a Cell of the pool.
The waker will drop without wake, if the token drop